==> OpenPatricianModel-0.0.2-sources.jar: ch/sahits/game/openpatrician/model/building/ITradingOffice.java <==
package ch.sahits.game.openpatrician.model.building;

import ch.sahits.game.openpatrician.model.IBalanceSheet;
import ch.sahits.game.openpatrician.model.product.AmountablePrice;
import ch.sahits.game.openpatrician.model.product.IWare;
import ch.sahits.game.openpatrician.model.weapon.IWeapon;

/**
 * The trading office (Kontor) is the trading point in a city. You can buy/sell between the trading
 * office and the city. You can move wares and wares between your storage and any ship currently in
 * the city.
 * @author Andi Hotz, (c) Sahits GmbH, 2011
 * Created on Dec 17, 2011
 *
 */
public interface ITradingOffice extends IBuilding{
	/**
	 * Retrieve the amount of ware in storage
	 * @param ware
	 * @return
	 */
	public AmountablePrice getWare(IWare ware);
	/**
	 * check if there are any weapons in storage
	 * @return
	 */
	public boolean hasWeapons();
	/**
	 * Add or remove ware from the storage. If the amount is negative it will be removed.
	 * If the full amount is not available only the available will be moved and returned.
	 * The amount is in the ware specific size.
	 * The price of the wares is computed based on the amount
	 * @param ware
	 * @param amount
	 * @return amount moved
	 */
	public int move(IWare ware, int amount);
	/**
	 * Add or remove weapon from the storage. If the amount is negative it will be removed.
	 * If the full amount is not available only the available will be moved and returned.
	 * The amount is in the ware specific size.
	 * @param weapons
	 * @param amount
	 * @return amount moved
	 */
	public int move(IWeapon weapons, int amount);
	/**
	 * Retrieve the storage capacity of the trading office and all other storages in the same city
	 * @return storage capacity in barrels
	 */
	public int getCapacity();
	/**
	 * Retrieve the total amount of the stored goods
	 * @return number of stored barrels
	 */
	public int getStored();
	/**
	 * Move the ware into/from the storage with a price attached.
	 * @param ware to be moved
	 * @param moved amount to be moved
	 * @param avgPrice average price to use on the amount of ware
	 */
	public int move(IWare ware, int moved, int avgPrice);
	/**
	 * Retrieve the balance sheet for last completed week.
	 * @return
	 */
	public IBalanceSheet getBalanceLastWeek();
	/**
	 * Retrieve the balance sheet for the current week
	 * @return
	 */
	public IBalanceSheet getCurrentWeek();
	/**
	 * Retrieve the steward of the trading office (manager). May be null if no manager is employed
	 * @return
	 */
	public ISteward getSteward();
	/**
	 * Get the trading object of the office
	 * @return
	 */
	public IAutomatedTrading getOfficeTrading();
	/**
	 * Retrieve the weapon storage for this trading office
	 * @return
	 */
	public IWeaponStorage getWeaponStorage();
	/**
	 * Retrieve an overview over the storage
	 * @return
	 */
	public IStorage getStorage();

}

==> OpenPatricianModel-0.6.0-sources.jar: ch/sahits/game/openpatrician/model/building/ITradingOffice.java <==
package ch.sahits.game.openpatrician.model.building;

import ch.sahits.game.openpatrician.model.city.ICity;
import javafx.beans.binding.BooleanBinding;
import javafx.beans.binding.IntegerBinding;
import javafx.beans.property.IntegerProperty;
import ch.sahits.game.openpatrician.model.IBalanceSheet;
import ch.sahits.game.openpatrician.model.product.IWare;
import ch.sahits.game.openpatrician.model.product.AmountablePrice;
import ch.sahits.game.openpatrician.model.weapon.IWeapon;
import javafx.beans.property.ObjectProperty;

/**
 * The trading office (Kontor) is the trading point in a city. You can buy/sell between the trading
 * office and the city. You can move wares and wares between your storage and any ship currently in
 * the city.
 * @author Andi Hotz, (c) Sahits GmbH, 2011
 * Created on Dec 17, 2011
 *
 */
public interface ITradingOffice extends IBuilding {
	/**
	 * Retrieve the amount of ware in storage
	 * @param ware
	 * @return
	 */
	public AmountablePrice<IWare> getWare(IWare ware);
	/**
	 * check if there are any weapons in storage
	 * @return
	 */
	public boolean hasWeapons();
	/**
	 * Add or remove ware from the storage. If the amount is negative it will be removed.
	 * If the full amount is not available only the available will be moved and returned.
	 * The amount is in the ware specific size.
	 * The price of the wares is computed based on the amount
	 * @param ware
	 * @param amount
	 * @return amount moved
	 */
	public int move(IWare ware, int amount);
	/**
	 * Add or remove weapon from the storage. If the amount is negative it will be removed.
	 * If the full amount is not available only the available will be moved and returned.
	 * The amount is in the ware specific size.
	 * @param weapons
	 * @param amount
	 * @return amount moved
	 */
	public int move(IWeapon weapons, int amount);
	/**
	 * Retrieve the storage capacity of the trading office and all other storages in the same city
	 * @return storage capacity in barrels
	 */
	public IntegerProperty capacityProperty();
	/**
	 * Move the ware into/from the storage with a price attached.
	 * @param ware to be moved
	 * @param moved amount to be moved
	 * @param avgPrice average price to use on the amount of ware
	 */
	public int move(IWare ware, int moved, int avgPrice);
	/**
	 * Retrieve the balance sheet for last completed week.
	 * @return
	 */
	public IBalanceSheet getBalanceLastWeek();
	/**
	 * Retrieve the balance sheet for the current week
	 * @return
	 */
	public IBalanceSheet getCurrentWeek();
	/**
	 * Retrieve the steward of the trading office (manager). May be null if no manager is employed
	 * @return
	 */
	public ISteward getSteward();
	/**
	 * Setting the steward. May be null to indicate firing the steward
	 * @param steward
	 */
	public void setSteward(ISteward steward);
	/**
	 * Get the trading object of the office
	 * @return
	 */
	public IAutomatedTrading getOfficeTrading();
	/**
	 * Retrieve the weapon storage for this trading office
	 * @return
	 */
	public IWeaponStorage getWeaponStorage();
	/**
	 * Retrieve an overview over the storage
	 * @return
	 */
	public IStorage getStorage();
	/**
	 * Binding representing the current stored amount.
	 * @return
	 */
	IntegerBinding storedAmountBinding();

    /**
     * Property holding the steward.
     * @return
     */
    ObjectProperty<ISteward> stewardProperty();

    /**
     * Binding indicating the presence of a steward.
     * @return
     */
    BooleanBinding storageManagerPresentBinding();

	/**
	 * Retrieve tha amount of occupied space not available to the player.
	 * @return
	 */
	int getOccupiedSpace();

	/**
	 * Set the amount of occupied space not available to the player.
	 * @param space
	 */
	void setOccupiedSpace(int space);

	/**
	 * Retrieve the city the trading office is located in.
	 * @return
	 */
	ICity getCity();
}
